@@ -1,27 +1,45 @@
 # -*- coding: utf-8 -*-
-
 # pylint: disable-msg=W0622
-"""cubicweb-forge application packaging information
-
-Copyright (c) 2003-2009 LOGILAB S.A. (Paris, FRANCE).
-http://www.logilab.fr/ -- mailto:contact@logilab.fr
-"""
+"""cubicweb-forge application packaging information"""
 modname = 'forge'
 distname = 'cubicweb-forge'
 
-numversion = (1, 2, 0)
+numversion = (1, 4, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
+copyright = '''Copyright (c) 2003-2010 LOGILAB S.A. (Paris, FRANCE).
+http://www.logilab.fr/ -- mailto:contact@logilab.fr'''
 
 author = 'LOGILAB S.A. (Paris, FRANCE)'
 author_email = 'contact@logilab.fr'
 
 short_desc = 'forge component for the CubicWeb framework'
-long_desc = '''This CubicWeb component provides a Forge application
+long_desc = '''
+This CubicWeb component provides a Forge application
 that supports the process of collaborative developing software.
 
-CubicWeb is a semantic web framework, see http://www.cubicweb.org
+Summary
+-------
+
+This cube provides a forge framework to support the process of collaborative
+developing software. This is built on the `tracker` cube and implements user
+friendly representation of the project: you can associate to a projet some
+screenshots, some attachments, a documentation page and so on.
+
+Depends
+-------
+You should have the following cubes installed:
+- card
+- comment
+- email
+- file
+- folder
+- mailinglist
+- tag
+- testcard
+- tracker
+- nosylist
 '''
 
 from os import listdir as _listdir
@@ -72,10 +90,11 @@ __depends_cubes__ = {'card': None,
                      'folder': '>= 1.1.0',
                      'mailinglist': '>= 1.1.0',
                      'tag': '>= 1.2.0',
-                     'tracker': '>= 1.1.0',
+                     'testcard': None,
+                     'tracker': '>= 1.3.0',
                      'nosylist': None,
                      }
-__depends__ = {'cubicweb': '>= 3.5.0',
+__depends__ = {'cubicweb': '>= 3.6.0',
                }
 for key,value in __depends_cubes__.items():
     __depends__['cubicweb-'+key] = value
