@@ -17,10 +17,10 @@ class VersionDocumentItemView(document.VersionDocumentItemView):
         super(VersionDocumentItemView, self).render_attributes(entity)
         etadate = entity.eta_date()
         if etadate is None:
-            etadate = self.req._('n/a')
+            etadate = self._cw._('n/a')
         else:
             etadate = self.format_date(etadate)
-        self.field(entity, self.req._('expected date'), etadate)
+        self.field(entity, self._cw._('expected date'), etadate)
 
 
 class TicketDocumentItemView(document.TicketDocumentItemView):
@@ -29,7 +29,7 @@ class TicketDocumentItemView(document.TicketDocumentItemView):
 
     def render_child(self, entity):
         if entity.reverse_comments:
-            self.w(u'%s ::\n\n' % self.req._('Comment_plural'))
+            self.w(u'%s ::\n\n' % self._cw._('Comment_plural'))
             for comment in entity.reverse_comments:
                 for line in comment.view('fullthreadtext_descending').splitlines():
                     self.w(u'  ' + line + '\n')
